#delim ;
version 8.2;
*
 Example do-file 2.
 Generate resultsset for testing eclplot
 (with multiple CIs for each predictor
 so the -supby()- option can be tested).
 This do-file requires the following SSC packages:
 somersd, parmest, sencode, eclplot
*;

clear;
set memory 1m;
set scheme s1mono;

* Create dataset for input to eclplot *;
sysuse auto, clear;
generate byte odd=mod(_n-1,2);
label define odd 0 "Even cars" 1 "Odd cars";
label value odd odd;
label variable odd "Odd or even cars";
parmby "somersd foreign price mpg headroom trunk weight length turn displacement gear_ratio, tr(z)",
 by(odd) label norestore stars(0.05 0.01 0.001)
 format(estimate min* max* %8.4g p %-8.2g stars %-3s);
sort odd parmseq;
sencode label, gene(predictor);
foreach X of var estimate min* max* {;
  replace `X'=exp(2*`X');
  replace `X'=(`X'-1)/(`X'+1);
};
label variable predictor "Predictor of non-American origin";
label variable estimate "Somers' D";
sort odd predictor;
by odd predictor: assert _N==1;
keep odd predictor estimate min* max* p stars;
order odd predictor estimate min* max* p stars;
describe;

* Create a plot using the by() option *;
eclplot estimate min95 max95 predictor,
  horizontal eplottype(scatter) rplottype(rcap)
  estopts( msize(large) mcolor(black) sort )
  ciopts( blcolor(black) msize(large) )
  xline( 0, lpattern(shortdash) style(default) )
  by(odd, style(compact) legend(off))
  yscale(range(0 10)) ylabel(1(1)9, grid glcolor(gs13))
  xlabel(-1(0.25)1, grid glcolor(gs13));
more;

* Create a plot using the supby() option *;
eclplot estimate min95 max95 predictor,
  horizontal eplottype(scatter) rplottype(rcap)
  supby( odd , spaceby(0.25) )
  estopts( msize(medlarge) mcolor(black) sort )
  ciopts( blcolor(black) msize(medlarge) )
  xline( 0, lpattern(shortdash) style(default) )
  yscale(range(0 10)) ylabel(1(1)9, grid glcolor(gs13))
  xlabel(-1(0.25)1, grid glcolor(gs13));
more;

exit;
